@@ -24,6 +24,10 @@ Full documentation can be found at:
 
 https://github.com/pietromandracci/gnuplot_manager
 
+To run a test script type::
+
+$ python3 -m gnuplot_manager.test
+
 
 List of available functions
 ===========================
